@@ -98,7 +98,7 @@ executioncommand = ""
 printcommand = ""
 githubactionsvariable = ""
 azurefilter = ""
-azurefilteronall = "false"
+azurefilteronall = "true"
 replaceretry = "false"
 webdriverio = "false"
 percentage = ""
@@ -330,13 +330,17 @@ def generate_sahi(teststocreate):
 ###############################################################################################################################
 #Main Script
 
+def strip_non_ascii(string):
+    ''' Returns the string without non ASCII characters'''
+    stripped = (c for c in string if 0 < ord(c) < 127)
+    return ''.join(stripped)
+
 #created at 3/3 from below should be kept up to date.  Refactor to use the same method for both
 def setVariables():
     if testtemplate == "azure dotnet":
         max_length = 28000
         variable_num = 1
         #moved new test section to else statement as if we are running all tests then no need to check for new
-        
         if len(testsrun) == 0 or testsrun == "all":
             print("no tests to set for azure")
             if azurefilteronall == "false":
@@ -373,7 +377,8 @@ def setVariables():
                             testtoadd = line
                             if encodetests == "true":
                                 testtoadd = testtoadd.replace("\\", "\\\\")
-                                testtoadd = testtoadd.replace("ö", "")
+                                testtoadd = strip_non_ascii(testtoadd)
+                                #testtoadd = testtoadd.replace("\\u00F6", "")
                                 testtoadd = testtoadd.replace("\n", "\\n")
                                 testtoadd = testtoadd.replace("(", "\(")
                                 testtoadd = testtoadd.replace(")", "\)")
@@ -656,7 +661,8 @@ def get_and_run_tests(type):
             testName = element["name"]
             if encodetests == "true":
                 testName = testName.replace("\\", "\\\\")
-                testtoadd = testtoadd.replace("ö", "")
+                testName = strip_non_ascii(testName)
+                #testtoadd = testtoadd.replace("\\u00F6", "")
                 testName = testName.replace("\n", "\\n")
                 testName = testName.replace("(", "\(")
                 testName = testName.replace(")", "\)")
@@ -1028,7 +1034,7 @@ def runtestswithappsurify(*args):
     testsuiteencoded=""
     projectencoded=""
     azurefilter = ""
-    azurefilteronall = "false"
+    azurefilteronall = "true"
     replaceretry = "false"
     webdriverio = "false"
     percentage = ""
@@ -1603,7 +1609,7 @@ def runtestswithappsurify(*args):
             if argv[k] == "--azurefilter":
                 azurefilter = argv[k+1]
             if argv[k] == "--azurefilteronall":
-                azurefilteronall = "true"
+                azurefilteronall = "false"
             if argv[k] == "--percentage":
                 percentage = argv[k+1]
             if argv[k] == "--weekendrunall":
@@ -1750,6 +1756,7 @@ def runtestswithappsurify(*args):
 
     weekno = datetime.datetime.today().weekday()
     if teststorun != "all" and teststorun != "none" and weekendrunall == "true" and weekno >= 5:
+        print("Weekend running all tests")
         testtypes=[]
 
 
@@ -1805,7 +1812,8 @@ def runtestswithappsurify(*args):
                         testtoadd = line
                         if encodetests == "true":
                             testtoadd = testtoadd.replace("\\", "\\\\")
-                            testtoadd = testtoadd.replace("ö", "")
+                            testtoadd = strip_non_ascii(testtoadd)
+                            #testtoadd = testtoadd.replace("\\u00F6", "")
                             testtoadd = testtoadd.replace("\n", "\\n")
                             testtoadd = testtoadd.replace("(", "\(")
                             testtoadd = testtoadd.replace(")", "\)")
@@ -1826,22 +1834,35 @@ def runtestswithappsurify(*args):
                 azurefilter = ""
             if azurefilter != "":
                 #print (f'##vso[task.setvariable variable={azure_variable}{variable_num}]{azurefilter}{testsrun}')
+                if azurefilter.endswith('&') is True:
+                    azurefilter = azurefilter[:-1]
+                if azurefilter.endswith('|') is True:
+                    azurefilter = azurefilter[:-1]
+                print ("running all tests")
                 print (f'##vso[task.setvariable variable={azure_variable}{variable_num}]{azurefilter}')
                 print (f'##vso[task.setvariable variable={azure_variable}]{azurefilter}')
             if azurefilter == "":
+                print ("running all tests")
                 #print (f'##vso[task.setvariable variable={azure_variable}{variable_num}]{testsrun}')
                 print (f'##vso[task.setvariable variable={azure_variable}]')
                 print (f'##vso[task.setvariable variable={azure_variable}{variable_num}]')
-            #print (f'##vso[task.setvariable variable={azurefilter}{azure_variable}{variable_num}]{testsrun}')
+            #print (f'##vso[task.setvariable variable={azurefilter}{azure_variable}{variable_num}]{testsrun}') 
         else:
-            print (f'##vso[task.setvariable variable={azure_variable}]{azurefilter}{testsrun}')
+            if azurefilter != "":
+                if azurefilter.endswith('&') is False and azurefilter.endswith('&') is False:
+                    azurefilter = azurefilter + "&"
+            print (f'##vso[task.setvariable variable={azure_variable}]{azurefilter}({testsrun})')
             while len(testsrun) > max_length:
                 split_string = testsrun.find("|Name=",max_length)
                 setval = testsrun[:split_string]
-                testsrun = testsrun[split_string:]                   
-                print (f'##vso[task.setvariable variable={azure_variable}{variable_num}]{azurefilter}{setval}')
+                if setval.startswith("|"):
+                    setval = setval[1:]
+                testsrun = testsrun[split_string:]
+                print (f'##vso[task.setvariable variable={azure_variable}{variable_num}]{azurefilter}({setval})')
                 variable_num = variable_num + 1
-            print (f'##vso[task.setvariable variable={azure_variable}{variable_num}]{azurefilter}{testsrun}')
+            if testsrun.startswith("|"):
+                testsrun = testsrun[1:]
+            print (f'##vso[task.setvariable variable={azure_variable}{variable_num}]{azurefilter}({testsrun})')
     #print("##vso[task.setvariable variable=BuildVersion;]998")
 
     #print("Execution command = " + executioncommand)
